python example
=====================

Just like the php-example, the `statsd-test.py` will insert statsd metrics into telegraf.

usage
-------------

0. Create a virtual environment
1. `pip3 install -r requirements.txt`
2. `python3 statsd-test.py`


Reference
-----------------

[statsd docs](https://statsd.readthedocs.io/en/latest/index.html)
